Each port that listens for traffic on a particular load balancer is configured separately and tied to the load balancer. Multiple listeners can be associated with the same load balancer but each must use a unique port.

Protocol: The protocol for which the front end listens. The TERMINATED_HTTPS protocol is only available if the key-manager service is enabled and you have authority to list certificate containers and secrets.

Port: The port on which the front end listens. Must be an integer from 1 to 65535.

Connection Limit: The maximum number of connections permitted for this listener. Default value is -1 which represents infinite connections.

Default Pool ID: The ID of the pool used by the listener if no L7 policies match.

Insert Headers: Additional headers insertion into HTTP header, only "X-Forwarded-For" and "X-Forwarded-Port" are supported.

Client Data Timeout: Frontend client inactivity timeout in milliseconds. Default: 50000.

TCP Inspect Timeout: Time, in milliseconds, to wait for additional TCP packets for content inspection. Default: 0.

Member Connect Timeout: Backend member connection timeout in milliseconds. Default: 5000.

Member Data Timeout: Backend member inactivity timeout in milliseconds. Default: 50000.